@@ -347,7 +347,7 @@ QRoutines* dirichlet_restrictions_CreateQRoutines(void)
    Returns:
      Pointer to sv->baseQ upon success and null otherwise.
 */
-int dirichlet_restrictions_ComputeTransitionMatrix(int t, TMarkovStateVariable *sv, TStateModel *model)
+int dirichlet_restrictions_ComputeTransitionMatrix(__attribute__ ((unused)) int t, TMarkovStateVariable *sv, __attribute__ ((unused)) TStateModel *model)
 {
   TDirichletRestrictions *restrictions=(TDirichletRestrictions*)(sv->info);
   int i, j, k;
@@ -535,7 +535,7 @@ int dirichlet_restrictions_DrawTransitionMatrixParametersFromPrior(TMarkovStateV
   Results:
     Sets sv->q to its prior mean.
 */
-int dirichlet_restrictions_DefaultTransitionMatrixParameters(TMarkovStateVariable *sv, TStateModel *model)
+int dirichlet_restrictions_DefaultTransitionMatrixParameters(TMarkovStateVariable *sv, __attribute__ ((unused)) TStateModel *model)
 {
   dirichlet_restrictions_SetTransitionMatrixParametersToPriorMean(sv->q,(TDirichletRestrictions*)(sv->info));
   return 1;
@@ -562,7 +562,7 @@ int dirichlet_restrictions_DefaultTransitionMatrixParameters(TMarkovStateVariabl
      Because of the checking done, care should be taken in calling this routine 
      in instances where efficiency is important.
 */
-int dirichlet_restrictions_Update_q_from_BaseTransitionMatrix(int t, TMarkovStateVariable *sv, TStateModel *model)
+int dirichlet_restrictions_Update_q_from_BaseTransitionMatrix(__attribute__ ((unused)) int t, TMarkovStateVariable *sv, __attribute__ ((unused)) TStateModel *model)
 {
   int i, j, k;
   PRECISION sum, *scale;
