@@ -1,27 +1,28 @@
-function simulations = simul_backward_linear_model(initialconditions, samplesize, DynareOptions, DynareModel, DynareOutput, innovations)
-
+function [simulations, errorflag] = simul_backward_linear_model(initialconditions, samplesize, options_, M_, oo_, innovations)
+% [simulations, errorflag] = simul_backward_linear_model(initialconditions, samplesize, options_, M_, oo_, innovations)
 % Simulates a stochastic linear backward looking model.
 %
 % INPUTS
-% - initialconditions   [double]      n*1 vector, initial conditions for the endogenous variables.
+% - initialconditions   [dseries]     initial conditions for the endogenous variables.
 % - samplesize          [integer]     scalar, number of periods for the simulation.
-% - DynareOptions       [struct]      Dynare's options_ global structure.
-% - DynareModel         [struct]      Dynare's M_ global structure.
-% - DynareOutput        [struct]      Dynare's oo_ global structure.
+% - options_            [struct]      Dynare's options_ global structure.
+% - M_                  [struct]      Dynare's M_ global structure.
+% - oo_                 [struct]      Dynare's oo_ global structure.
 % - innovations         [double]      T*q matrix, innovations to be used for the simulation.
 %
 % OUTPUTS
-% - DynareOutput        [struct]      Dynare's oo_ global structure.
+% - oo_                 [struct]      Dynare's oo_ global structure.
+% - errorflag           [logical]     scalar, equal to false iff the simulation did not fail.
 %
 % REMARKS
-% [1] The innovations used for the simulation are saved in DynareOutput.exo_simul, and the resulting paths for the endogenous
-%     variables are saved in DynareOutput.endo_simul.
+% [1] The innovations used for the simulation are saved in oo_.exo_simul, and the resulting paths for the endogenous
+%     variables are saved in oo_.endo_simul.
 % [2] The last input argument is not mandatory. If absent we use random draws and rescale them with the informations provided
 %     through the shocks block.
 % [3] If the first input argument is empty, the endogenous variables are initialized with 0, or if available with the informations
 %     provided thrtough the histval block.
 
-% Copyright (C) 2012-2017 Dynare Team
+% Copyright © 2012-2023 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -38,11 +39,11 @@ function simulations = simul_backward_linear_model(initialconditions, samplesize
 % You should have received a copy of the GNU General Public License
 % along with Dynare.  If not, see <https://www.gnu.org/licenses/>.
 
-if DynareModel.maximum_lead
+if M_.maximum_lead
     error('Model defined in %s.mod is not backward.', M_.fname)
 end
 
-if ~DynareModel.maximum_lag
+if ~M_.maximum_lag
     error('Model defined in %s.mod is not backward.', M_.fname)
 end
 
@@ -50,9 +51,9 @@ if nargin<6
     innovations = [];
 end
 
-[initialconditions, samplesize, innovations, DynareOptions, DynareModel, DynareOutput, endonames, exonames, nx, ny1, iy1, jdx, model_dynamic] = ...
-    simul_backward_model_init(initialconditions, samplesize, DynareOptions, DynareModel, DynareOutput, innovations);
+[initialconditions, samplesize, innovations, options_, M_, oo_, endonames, exonames, dynamic_resid, dynamic_g1] = ...
+    simul_backward_model_init(initialconditions, samplesize, options_, M_, oo_, innovations);
 
-[ysim, xsim] = simul_backward_linear_model_(initialconditions, samplesize, DynareOptions, DynareModel, DynareOutput, innovations, nx, ny1, iy1, jdx, model_dynamic);
+[ysim, xsim, errorflag] = simul_backward_linear_model_(initialconditions, samplesize, options_, M_, oo_, innovations, dynamic_resid, dynamic_g1);
 
-simulations = [dseries(ysim', initialconditions.init, endonames(1:DynareModel.orig_endo_nbr)), dseries(xsim, initialconditions.init, exonames)];
\ No newline at end of file
+simulations = [dseries(ysim', initialconditions.init, endonames(1:M_.orig_endo_nbr)), dseries(xsim, initialconditions.init, exonames)];
