@@ -81,7 +81,7 @@ iyr0 = find(iyv(:)) ;
 z = z(iyr0);
 it_ = M_.maximum_lag + 1 ;
 
-[junk,jacobia_] = feval([M_.fname '.dynamic'],z,zeros(M_.exo_nbr+M_.exo_det_nbr,klen), M_.params, ys, it_);
+[junk,jacobia_] = feval([M_.fname '.dynamic'],z,zeros(klen,M_.exo_nbr+M_.exo_det_nbr), M_.params, ys, it_);
 if max(abs(junk))>options_.solve_tolf
      info = 65; %the model must be written in deviation form and not have constant terms or have a steady state provided
      return;
