@@ -26,7 +26,7 @@ function [opt_par_values,fval,exitflag,hessian_mat,options_,Scale,new_rat_hess_i
 %   none.
 %
 %
-% Copyright (C) 2014-2021 Dynare Team
+% Copyright © 2014-2023 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -107,23 +107,23 @@ switch minimizer_algorithm
     if options_.analytic_derivation || (isfield(options_,'mom') && options_.mom.analytic_jacobian==1) %use wrapper
         func = @(x) analytic_gradient_wrapper(x,objective_function,varargin{:});
         if ~isoctave
-            [opt_par_values,fval,exitflag,output,lamdba,grad,hessian_mat] = ...
+            [opt_par_values,fval,exitflag,~,~,~,hessian_mat] = ...
                 fmincon(func,start_par_value,[],[],[],[],bounds(:,1),bounds(:,2),[],optim_options);
         else
             % Under Octave, use a wrapper, since fmincon() does not have an 11th
             % arg. Also, only the first 4 output arguments are available.
-            [opt_par_values,fval,exitflag,output] = ...
+            [opt_par_values,fval,exitflag] = ...
                 fmincon(func,start_par_value,[],[],[],[],bounds(:,1),bounds(:,2),[],optim_options);
         end
     else
         if ~isoctave
-            [opt_par_values,fval,exitflag,output,lamdba,grad,hessian_mat] = ...
+            [opt_par_values,fval,exitflag,~,~,~,hessian_mat] = ...
                 fmincon(objective_function,start_par_value,[],[],[],[],bounds(:,1),bounds(:,2),[],optim_options,varargin{:});
         else
             % Under Octave, use a wrapper, since fmincon() does not have an 11th
             % arg. Also, only the first 4 output arguments are available.
             func = @(x) objective_function(x,varargin{:});
-            [opt_par_values,fval,exitflag,output] = ...
+            [opt_par_values,fval,exitflag] = ...
                 fmincon(func,start_par_value,[],[],[],[],bounds(:,1),bounds(:,2),[],optim_options);
         end    
     end
@@ -177,7 +177,7 @@ switch minimizer_algorithm
     end
     sa_options.initial_step_length= sa_options.initial_step_length*ones(npar,1); %bring step length to correct vector size
     sa_options.step_length_c= sa_options.step_length_c*ones(npar,1); %bring step_length_c to correct vector size
-    [opt_par_values, fval,exitflag, n_accepted_draws, n_total_draws, n_out_of_bounds_draws, t, vm] =...
+    [opt_par_values, fval,exitflag] =...
         simulated_annealing(objective_function,start_par_value,sa_options,LB,UB,varargin{:});
   case 3
     if isoctave && ~user_has_octave_forge_package('optim')
@@ -263,20 +263,20 @@ switch minimizer_algorithm
         Verbose = 0;
     end
     % Set flag for analytical gradient.
-    if options_.analytic_derivation
+    if options_.analytic_derivation || (isfield(options_,'mom') && options_.mom.analytic_jacobian==1)
         analytic_grad=1;
     else
         analytic_grad=[];
     end
     % Call csminwell.
-    [fval,opt_par_values,grad,inverse_hessian_mat,itct,fcount,exitflag] = ...
+    [fval,opt_par_values,~,inverse_hessian_mat,~,~,exitflag] = ...
         csminwel1(objective_function, start_par_value, H0, analytic_grad, crit, nit, numgrad, epsilon, Verbose, Save_files, varargin{:});
     hessian_mat=inv(inverse_hessian_mat);
   case 5
     if isempty(prior_information) %mr_hessian requires it, but can be NaN
         prior_information.p2=NaN(n_params,1);
     end
-    if options_.analytic_derivation 
+    if options_.analytic_derivation
         old_analytic_derivation = options_.analytic_derivation;
         options_.analytic_derivation=-1; %force analytic outer product gradient hessian for each iteration
         analytic_grad=1;
@@ -288,6 +288,9 @@ switch minimizer_algorithm
         newratflag = options_.newrat.hess; %default
     end
     nit=options_.newrat.maxiter;
+    robust = options_.newrat.robust;
+    gstep_crit = options_.newrat.tolerance.gstep;
+    gstep_crit_rel = options_.newrat.tolerance.gstep_rel;
     Verbose = options_.newrat.verbosity;
     Save_files = options_.newrat.Save_files;
     if ~isempty(options_.optim_opt)
@@ -303,8 +306,14 @@ switch minimizer_algorithm
                 else
                     newratflag=flag;
                 end
+              case 'robust'
+                robust = options_list{i,2};
               case 'TolFun'
                 crit = options_list{i,2};
+              case 'TolGstep'
+                gstep_crit = options_list{i,2};
+              case 'TolGstepRel'
+                gstep_crit_rel = options_list{i,2};
               case 'verbosity'
                 Verbose = options_list{i,2};
               case 'SaveFiles'
@@ -318,12 +327,17 @@ switch minimizer_algorithm
         Save_files = 0;
         Verbose = 0;
     end
+    if isnan(gstep_crit)
+        gstep_crit = crit;
+    end
     hess_info.gstep=options_.gstep;
-    hess_info.htol = 1.e-4;
+    hess_info.htol = gstep_crit;
+    hess_info.htol_rel = gstep_crit_rel;
     hess_info.h1=options_.gradient_epsilon*ones(n_params,1);
+    hess_info.robust=robust;
     % here we force 7th input argument (flagg) to be 0, since outer product
     % gradient Hessian is handled in dynare_estimation_1
-    [opt_par_values,hessian_mat,gg,fval,invhess,new_rat_hess_info] = newrat(objective_function,start_par_value,bounds,analytic_grad,crit,nit,0,Verbose,Save_files,hess_info,prior_information.p2,options_.gradient_epsilon,parameter_names,varargin{:});    %hessian_mat is the plain outer product gradient Hessian
+    [opt_par_values,hessian_mat,~,fval,~,new_rat_hess_info] = newrat(objective_function,start_par_value,bounds,analytic_grad,crit,nit,0,Verbose,Save_files,hess_info,prior_information.p2,options_.gradient_epsilon,parameter_names,varargin{:});    %hessian_mat is the plain outer product gradient Hessian
     new_rat_hess_info.new_rat_hess_info = new_rat_hess_info;
     new_rat_hess_info.newratflag = newratflag;
     if options_.analytic_derivation 
@@ -353,9 +367,9 @@ switch minimizer_algorithm
         [opt_par_values,fval,exitflag] = fminsearch(objective_function,start_par_value,optim_options,varargin{:});
     else
         % Under Octave, use a wrapper, since fminsearch() does not have a
-        % 4th arg, and only has two output args
+        % 4th arg.
         func = @(x) objective_function(x,varargin{:});
-        [opt_par_values,fval] = fminsearch(func,start_par_value,optim_options);
+        [opt_par_values,fval,exitflag] = fminsearch(func,start_par_value,optim_options);
     end
   case 8
     % Dynare implementation of the simplex algorithm.
@@ -439,7 +453,7 @@ switch minimizer_algorithm
     end
     warning('off','CMAES:NonfinitenessRange');
     warning('off','CMAES:InitialSigma');
-    [x, fval, COUNTEVAL, STOPFLAG, OUT, BESTEVER] = cmaes(func2str(objective_function),start_par_value,H0,cmaesOptions,varargin{:});
+    [~, ~, ~, ~, ~, BESTEVER] = cmaes(func2str(objective_function),start_par_value,H0,cmaesOptions,varargin{:});
     opt_par_values=BESTEVER.x;
     fval=BESTEVER.f;
   case 10
@@ -484,7 +498,7 @@ switch minimizer_algorithm
   case 11
     options_.cova_compute = 0;
     subvarargin = [varargin(1), varargin(3:6), varargin(8)];
-    [opt_par_values, stdh, lb_95, ub_95, med_param] = online_auxiliary_filter(start_par_value, subvarargin{:});
+    opt_par_values = online_auxiliary_filter(start_par_value, subvarargin{:});
   case 12
     if isoctave
         error('Option mode_compute=12 is not available under Octave')
@@ -498,10 +512,10 @@ switch minimizer_algorithm
     if ~isempty(options_.optim_opt)
         options_list = read_key_value_string(options_.optim_opt);
         SupportedListOfOptions = {'CreationFcn', 'Display', 'DisplayInterval', 'FunctionTolerance', ...
-                            'FunValCheck', 'HybridFcn', 'InertiaRange', 'InitialSwarmMatrix', 'InitialSwarmSpan', ...
-                            'MaxIterations', 'MaxStallIterations', 'MaxStallTime', 'MaxTime', ...
-                            'MinNeighborsFraction', 'ObjectiveLimit', 'OutputFcn', 'PlotFcn', 'SelfAdjustmentWeight', ...
-                            'SocialAdjustmentWeight', 'SwarmSize', 'UseParallel', 'UseVectorized'};
+                                  'FunValCheck', 'HybridFcn', 'InertiaRange', 'InitialSwarmMatrix', 'InitialSwarmSpan', ...
+                                  'MaxIterations', 'MaxStallIterations', 'MaxStallTime', 'MaxTime', ...
+                                  'MinNeighborsFraction', 'ObjectiveLimit', 'OutputFcn', 'PlotFcn', 'SelfAdjustmentWeight', ...
+                                  'SocialAdjustmentWeight', 'SwarmSize', 'UseParallel', 'UseVectorized'};
         for i=1:rows(options_list)
             if ismember(options_list{i,1}, SupportedListOfOptions)
                 particleswarmOptions = optimoptions(particleswarmOptions, options_list{i,1}, options_list{i,2});
@@ -515,7 +529,7 @@ switch minimizer_algorithm
     % Set objective function.
     objfun = @(x) objective_function(x, varargin{:});
     if ischar(particleswarmOptions.SwarmSize)
-        eval(['particleswarmOptions.SwarmSize = ' particleswarmOptions.SwarmSize ';'])
+        particleswarmOptions.SwarmSize = str2num(particleswarmOptions.SwarmSize);
     end
     if isempty(particleswarmOptions.InitialSwarmMatrix)
         particleswarmOptions.InitialSwarmMatrix = zeros(particleswarmOptions.SwarmSize, numberofvariables);
@@ -523,7 +537,7 @@ switch minimizer_algorithm
         FVALS = zeros(particleswarmOptions.SwarmSize, 1);
         while p<=particleswarmOptions.SwarmSize
             candidate = rand(numberofvariables, 1).*(UB-LB)+LB;
-            [fval, info, exit_flag] = objfun(candidate);
+            [fval, ~, exit_flag] = objfun(candidate);
             if exit_flag
                 particleswarmOptions.InitialSwarmMatrix(p,:) = transpose(candidate);
                 FVALS(p) = fval;
@@ -538,7 +552,7 @@ switch minimizer_algorithm
     % Define penalized objective.
     objfun = @(x) penalty_objective_function(x, objective_function, penalty, varargin{:});
     % Minimize the penalized objective (note that the penalty is not updated).
-    [opt_par_values, fval, exitflag, output] = particleswarm(objfun, length(start_par_value), LB, UB, particleswarmOptions);
+    [opt_par_values, fval, exitflag] = particleswarm(objfun, length(start_par_value), LB, UB, particleswarmOptions);
     opt_par_values = opt_par_values(:);
   case 13
     % Matlab's lsqnonlin (Optimization toolbox needed).
@@ -566,21 +580,21 @@ switch minimizer_algorithm
         optim_options.Display='off';
     end
     if options_.analytic_derivation || (isfield(options_,'mom') && options_.mom.analytic_jacobian==1)
-        if isoctave || matlab_ver_less_than('9.0') % Option names changed in MATLAB R2016a
+        if isoctave
             optim_options.Jacobian = 'on';
         else
             optim_options.SpecifyObjectiveGradient = true;
         end
         func = @(x) analytic_gradient_wrapper(x,objective_function,varargin{:});
-        [opt_par_values,Resnorm,fval,exitflag,OUTPUT,LAMBDA,JACOB] = ...
+        [opt_par_values,~,fval,exitflag] = ...
             lsqnonlin(func,start_par_value,bounds(:,1),bounds(:,2),optim_options);
     else
         if ~isoctave
-            [opt_par_values,Resnorm,fval,exitflag,OUTPUT,LAMBDA,JACOB] = lsqnonlin(objective_function,start_par_value,bounds(:,1),bounds(:,2),optim_options,varargin{:});
+            [opt_par_values,~,fval,exitflag] = lsqnonlin(objective_function,start_par_value,bounds(:,1),bounds(:,2),optim_options,varargin{:});
         else
             % Under Octave, use a wrapper, since lsqnonlin() does not have a 6th arg
             func = @(x)objective_function(x,varargin{:});
-            [opt_par_values,Resnorm,fval,exitflag,OUTPUT,LAMBDA,JACOB] = lsqnonlin(func,start_par_value,bounds(:,1),bounds(:,2),optim_options);
+            [opt_par_values,~,fval,exitflag] = lsqnonlin(func,start_par_value,bounds(:,1),bounds(:,2),optim_options);
         end
     end    
   case 101
@@ -642,7 +656,7 @@ switch minimizer_algorithm
         end
     end
     func = @(x)objective_function(x,varargin{:});
-    [opt_par_values,fval,exitflag,output] = simulannealbnd(func,start_par_value,bounds(:,1),bounds(:,2),optim_options);
+    [opt_par_values,fval,exitflag] = simulannealbnd(func,start_par_value,bounds(:,1),bounds(:,2),optim_options);
   otherwise
     if ischar(minimizer_algorithm)
         if exist(minimizer_algorithm)
