@@ -62,7 +62,7 @@ function [fOutVar,nBlockPerCPU, totCPU] = masterParallel(Parallel,fBlock,nBlock,
 %                              the number of CPUs declared in "Parallel", if
 %                              the number of required threads is lower)
 
-% Copyright (C) 2009-2017 Dynare Team
+% Copyright © 2009-2017 Dynare Team
 %
 % This file is part of Dynare.
 %
@@ -102,7 +102,7 @@ if nargin>8 && initialize==1
         evalin('base','clear PRCDirTmp,')
     else
         % Delete the traces (if existing) of last local session of computations.
-        mydelete(['slaveParallel_input*.mat']);
+        mydelete('slaveParallel_input*.mat');
     end
     return
 end
@@ -169,7 +169,7 @@ if parallel_recover ==0
     DyMo=pwd;
     % fInputVar.DyMo=DyMo;
     if ispc
-        [tempo, MasterName]=system('hostname');
+        [~, MasterName]=system('hostname');
         MasterName=deblank(MasterName);
     end
     % fInputVar.MasterName = MasterName;
@@ -183,11 +183,11 @@ if parallel_recover ==0
 
       case 1
         if exist('fGlobalVar','var')
-            save(['temp_input.mat'],'fInputVar','fGlobalVar')
+            save('temp_input.mat','fInputVar','fGlobalVar')
         else
-            save(['temp_input.mat'],'fInputVar')
+            save('temp_input.mat','fInputVar')
         end
-        save(['temp_input.mat'],'Parallel','-append')
+        save('temp_input.mat','Parallel','-append')
         closeSlave(Parallel,PRCDir,-1);
     end
 
@@ -362,7 +362,7 @@ if parallel_recover ==0
                             itmp = bitset(itmp,cpus(icpu));
                         end
                         hex_affinity = dec2hex(itmp);
-                        token1 = ['start /B /D "',DyMo, '" /affinity ',hex_affinity,' /LOW  '];
+                        token1 = ['start "" /B /D "',DyMo, '" /affinity ',hex_affinity,' /LOW  '];
                     end
                     if  regexpi([Parallel(indPC).MatlabOctavePath], 'octave')
                         command1=[token1,Parallel(indPC).MatlabOctavePath,' -f --eval "default_save_options(''-v7''); addpath(''',Parallel(indPC).DynarePath,'''), dynareroot = dynare_config(); fParallel(',int2str(offset+1),',',int2str(sum(nBlockPerCPU(1:j))),',',int2str(j),',',int2str(indPC),',''',fname,''')"'];
@@ -378,7 +378,7 @@ if parallel_recover ==0
 
                 if (~ispc || strcmpi('unix',Parallel(indPC).OperatingSystem)) % Hybrid computing Windows <-> Unix!
                     if ispc
-                        token='start /B ';
+                        token='start "" /B ';
                     else
                         token = '';
                     end
@@ -444,7 +444,7 @@ if parallel_recover ==0
                             itmp = bitset(itmp,cpus(icpu));
                         end
                         hex_affinity = dec2hex(itmp);
-                        token1 = ['start /B /D "',DyMo, '" /affinity ',hex_affinity,' /LOW  '];
+                        token1 = ['start "" /B /D "',DyMo, '" /affinity ',hex_affinity,' /LOW  '];
                     end
                     if  regexpi([Parallel(indPC).MatlabOctavePath], 'octave')
                         command1=[token1,Parallel(indPC).MatlabOctavePath,' -f --eval "default_save_options(''-v7'');addpath(''',Parallel(indPC).DynarePath,'''), dynareroot = dynare_config(); slaveParallel(',int2str(j),',',int2str(indPC),')"'];
@@ -464,7 +464,7 @@ if parallel_recover ==0
                     dynareParallelSendFiles(['slaveParallel_input',int2str(j),'.mat'],PRCDir,Parallel(indPC))
                     if (~ispc || strcmpi('unix',Parallel(indPC).OperatingSystem)) % Hybrid computing Windows <-> Unix!
                         if ispc
-                            token='start /B ';
+                            token='start "" /B ';
                         else
                             token = '';
                         end
@@ -608,7 +608,7 @@ if parallel_recover ==0
             hstatus(j) = axes('position',[0.05/ncol+(jcol-1)/ncol vstart-vspace*(jrow-1) 0.9/ncol 0.3*vspace], ...
                               'box','on','xtick',[],'ytick',[],'xlim',[0 1],'ylim',[0 1]);
             hpat(j) = patch([0 0 0 0],[0 1 1 0],'r','EdgeColor','r');
-            htit(j) = title(['Initialize ...']);
+            htit(j) = title('Initialize ...');
 
         end
 
@@ -710,11 +710,7 @@ if parallel_recover ==0
                 pcerdone(j) = prtfrc;
                 idCPU(j) = njob;
                 if isoctave || options_.console_mode
-                    if (~ispc || strcmpi('unix',Parallel(indPC).OperatingSystem))
-                        statusString = [statusString, int2str(j), ' %3.f%% done! '];
-                    else
-                        statusString = [statusString, int2str(j), ' %3.f%% done! '];
-                    end
+                    statusString = [statusString, int2str(j), ' %3.f%% done! '];
                 else
                     status_String{j} = waitbarString;
                     status_Title{j} = waitbarTitle;
@@ -722,11 +718,7 @@ if parallel_recover ==0
             catch % ME
                   % To define!
                 if isoctave || options_.console_mode
-                    if (~ispc || strcmpi('unix',Parallel(indPC).OperatingSystem))
-                        statusString = [statusString, int2str(j), ' %3.f%% done! '];
-                    else
-                        statusString = [statusString, int2str(j), ' %3.f%% done! '];
-                    end
+                    statusString = [statusString, int2str(j), ' %3.f%% done! '];
                 end
             end
         end
@@ -901,7 +893,7 @@ switch Strategy
         end
 
         if isempty(dir('dynareParallelLogFiles'))
-            [A B C]=rmdir('dynareParallelLogFiles');
+            [~,~]=rmdir('dynareParallelLogFiles'); %use outputs to not trigger hard error
             mkdir('dynareParallelLogFiles');
         end
         try
@@ -910,16 +902,16 @@ switch Strategy
         catch
         end
 
-        mydelete(['*_core*_input*.mat']);
+        mydelete('*_core*_input*.mat');
 
     end
 
     delete ConcurrentCommand1.bat
   case 1
-    delete(['temp_input.mat'])
+    delete('temp_input.mat')
     if newInstance
         if isempty(dir('dynareParallelLogFiles'))
-            [A B C]=rmdir('dynareParallelLogFiles');
+            [~,~]=rmdir('dynareParallelLogFiles'); %use outputs to not trigger hard error
             mkdir('dynareParallelLogFiles');
         end
     end
